@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQBUTTON_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QButton class
-// For Qt3, no changes are needed
-
 #include <ntqbutton.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QButton class
-// For Qt4, some changes are needed
-
-#include <Qt/q3button.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQBUTTON_H */
