@@ -23,21 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQNETWORK_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Pull in Qt3 qnetwork defines
-
 #include <ntqnetwork.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Pull in Qt4 qnetwork defines
-
-#include <ntqnetwork.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQNETWORK_H */
