@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQPTRCOLLECTION_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QPtrCollection class
-// For Qt3, no changes are needed
-
 #include <ntqptrcollection.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QPtrCollection class
-// For Qt4, some changes are needed
-
-#include <Qt/q3ptrcollection.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQPTRCOLLECTION_H */
