@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQWIDGETSTACK_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QWidgetStack class
-// For Qt3, no changes are needed
-
 #include <ntqwidgetstack.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QWidgetStack class
-// For Qt4, some changes are needed
-
-#include <Qt/q3widgetstack.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQWIDGETSTACK_H */
